@@ -19,12 +19,14 @@ fn bernoulli() -> Result<(), String> {
     println!("Bernoulli-Bar counting successes (42 / 60) and attempts (# 130)");
     let mut progressbar = progressing::BernoulliBar::from_goal(60);
     progressbar.set_bar_len(20);
-    progressbar.set((42, 130).into()).reprintln()
+    progressbar.set((42, 130)).reprintln()
 }
 
 fn main() -> Result<(), String> {
     clamped()?;
+    println!();
     mapped()?;
+    println!();
     bernoulli()?;
 
     Ok(())
